| /llvm-project-15.0.7/clang/test/Analysis/ |
| H A D | MismatchedDeallocator-checker-test.mm | 104 …delete[] p; // expected-warning{{Memory allocated by 'new' should be deallocated by 'delete', not … 109 …delete[] p; // expected-warning{{Memory allocated by operator new should be deallocated by 'delete… 118 …delete p; // expected-warning{{Memory allocated by 'new[]' should be deallocated by 'delete[]', no… 123 …delete p; // expected-warning{{Memory allocated by operator new[] should be deallocated by 'delete… 139 delete &i; // no-warning 145 delete p2; 146 delete p2; // no-warning 160 delete p; // no-warning 191 delete p; 197 delete p; [all …]
|
| /llvm-project-15.0.7/llvm/test/tools/llvm-ar/ |
| H A D | mri-delete.test | 8 ## Basic delete. 71 delete elf.o 78 delete elf.o 86 delete bad.o 96 delete elf.o 106 delete elf.o 116 delete elf.o 123 delete elf.o 126 delete elf.o 134 delete elf.o [all …]
|
| H A D | thin-archive.test | 5 RUN: cp %t/foo/bar/elf.o %t/delete.o 9 RUN: llvm-ar rc --thin %t/absolute-1a.ar %t/foo/elf.o %t/delete.o %t/foo/bar/elf.o 10 RUN: llvm-ar --thin d %t/absolute-1a.ar delete.o 15 RUN: llvm-ar rTc %t/absolute-1b.ar %t/foo/elf.o %t/delete.o %t/foo/bar/elf.o 16 RUN: llvm-ar dT %t/absolute-1b.ar delete.o 24 RUN: cd %t/foo && llvm-ar dT bar/absolute-2.ar %t/delete.o 31 RUN: cd %t/foo && llvm-ar rTc ../relative-1.ar elf.o ../delete.o bar/elf.o 32 RUN: cd %t/foo && llvm-ar dT ../relative-1.ar delete.o 39 RUN: cd %t/foo && llvm-ar rTc %t/relative-2.ar elf.o ../delete.o bar/elf.o 40 RUN: cd %t/foo && llvm-ar dT %t/relative-2.ar delete.o [all …]
|
| /llvm-project-15.0.7/libcxx/test/std/utilities/tuple/tuple.tuple/tuple.assign/ |
| H A D | types.h | 22 constexpr const CopyAssign& operator=(const CopyAssign&) const = delete; 23 constexpr CopyAssign& operator=(CopyAssign&&) = delete; 24 constexpr const CopyAssign& operator=(CopyAssign&&) const = delete; 38 constexpr ConstCopyAssign& operator=(const ConstCopyAssign&) = delete; 39 constexpr ConstCopyAssign& operator=(ConstCopyAssign&&) = delete; 40 constexpr const ConstCopyAssign& operator=(ConstCopyAssign&&) const = delete; 51 constexpr MoveAssign& operator=(const MoveAssign&) = delete; 52 constexpr const MoveAssign& operator=(const MoveAssign&) const = delete; 53 constexpr const MoveAssign& operator=(MoveAssign&&) const = delete; 67 constexpr ConstMoveAssign& operator=(const ConstMoveAssign&) = delete; [all …]
|
| /llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/ |
| H A D | new | 68 __device__ inline void operator delete(void *ptr, 70 ::operator delete(ptr); 74 ::operator delete(ptr); 76 __device__ inline void operator delete[](void *ptr, 78 ::operator delete(ptr); 81 // Sized delete, C++14 only. 83 __device__ inline void operator delete(void *ptr, 85 ::operator delete(ptr); 87 __device__ inline void operator delete[](void *ptr, 89 ::operator delete(ptr); [all …]
|
| /llvm-project-15.0.7/llvm/include/llvm/Transforms/Scalar/ |
| H A D | GVNExpression.h | 69 Expression(const Expression &) = delete; 151 BasicExpression() = delete; 276 MemoryExpression() = delete; 309 CallExpression() = delete; 341 LoadExpression() = delete; 380 StoreExpression() = delete; 421 AggregateValueExpression() = delete; 512 PHIExpression() = delete; 513 PHIExpression(const PHIExpression &) = delete; 558 VariableExpression() = delete; [all …]
|
| /llvm-project-15.0.7/clang-tools-extra/docs/clang-tidy/checks/hicpp/ |
| H A D | use-equals-delete.rst | 1 .. title:: clang-tidy - hicpp-use-equals-delete 3 :http-equiv=refresh: 5;URL=../modernize/use-equals-delete.html 5 hicpp-use-equals-delete 8 This check is an alias for `modernize-use-equals-delete <../modernize/use-equals-delete.html>`_. 9 … <http://www.codingstandard.com/rule/12-5-1-define-explicitly-default-or-delete-implicit-special-m… 10 to explicitly default or delete special member functions.
|
| H A D | new-delete-operators.rst | 1 .. title:: clang-tidy - hicpp-new-delete-operators 3 :http-equiv=refresh: 5;URL=../misc/new-delete-overloads.html 5 hicpp-new-delete-operators 8 This check is an alias for `misc-new-delete-overloads <../misc/new-delete-overloads.html>`_. 10 the `new` and `delete` operators have the correct signature.
|
| /llvm-project-15.0.7/clang/test/SemaObjCXX/ |
| H A D | block-capture.mm | 18 // "pure" C++98 tests (pretend 'delete' means 'private'). 23 ConstCopyOnly(ConstCopyOnly &) = delete; // cxx98-note {{marked deleted here}} 31 NonConstCopyOnly(const NonConstCopyOnly &) = delete; // cxx11_2b-note {{marked deleted here}} field 38 CopyNoMove(CopyNoMove &&) = delete; // cxx98_2b-note {{marked deleted here}} 44 MoveOnly(MoveOnly &) = delete; field 51 NoCopyNoMove(NoCopyNoMove &) = delete; 52 NoCopyNoMove(NoCopyNoMove &&) = delete; // cxx98_2b-note {{marked deleted here}} 58 ConvertingRVRef(ConvertingRVRef &) = delete; field 62 operator X() const & = delete; field 74 operator X() && = delete; // cxx98_2b-note {{marked deleted here}} [all …]
|
| /llvm-project-15.0.7/clang/lib/Headers/openmp_wrappers/ |
| H A D | __clang_openmp_device_functions.h | 87 inline void operator delete(void *ptr)OPENMP_NOEXCEPT { ::free(ptr); } in delete() function 89 inline void operator delete[](void *ptr) OPENMP_NOEXCEPT { 90 ::operator delete(ptr); 95 inline void operator delete(void *ptr, __SIZE_TYPE__ size)OPENMP_NOEXCEPT { in delete() function 96 ::operator delete(ptr); in delete() 98 inline void operator delete[](void *ptr, __SIZE_TYPE__ size) OPENMP_NOEXCEPT { 99 ::operator delete(ptr);
|
| /llvm-project-15.0.7/libcxx/include/ |
| H A D | new | 57 void operator delete(void* ptr) noexcept; // replaceable 60 void operator delete(void* ptr, std::size_t size, 63 void operator delete(void* ptr, std:align_val_t alignment, 74 void operator delete[](void* ptr, 76 void operator delete[](void* ptr, std::size_t size, 79 void operator delete[](void* ptr, std::align_val_t alignment, 84 void operator delete (void* ptr, void*) noexcept; 85 void operator delete[](void* ptr, void*) noexcept; 193 _LIBCPP_OVERRIDABLE_FUNC_VIS void operator delete(void* __p) _NOEXCEPT; 201 _LIBCPP_OVERRIDABLE_FUNC_VIS void operator delete[](void* __p) _NOEXCEPT; [all …]
|
| H A D | mutex | 25 mutex(const mutex&) = delete; 26 mutex& operator=(const mutex&) = delete; 59 timed_mutex(const timed_mutex&) = delete; 107 lock_guard(lock_guard const&) = delete; 120 scoped_lock(scoped_lock const&) = delete; 142 unique_lock(unique_lock const&) = delete; 178 once_flag(const once_flag&) = delete; 247 timed_mutex(const timed_mutex&) = delete; 487 scoped_lock(scoped_lock const&) = delete; 507 scoped_lock(scoped_lock const&) = delete; [all …]
|
| /llvm-project-15.0.7/libcxx/test/support/ |
| H A D | archetypes.ipp | 59 DEFINE_EXPLICIT NoCtors() DEFINE_NOEXCEPT = delete; 60 DEFINE_EXPLICIT NoCtors(NoCtors const&) DEFINE_NOEXCEPT = delete; 61 NoCtors& operator=(NoCtors const&) DEFINE_NOEXCEPT = delete; 68 DEFINE_EXPLICIT DEFINE_CONSTEXPR NoDefault() DEFINE_NOEXCEPT = delete; 76 DefaultOnly(DefaultOnly const&) DEFINE_NOEXCEPT = delete; 77 DefaultOnly& operator=(DefaultOnly const&) DEFINE_NOEXCEPT = delete; 97 CopyOnly &operator=(CopyOnly &&) DEFINE_NOEXCEPT = delete; 106 NonCopyable &operator=(NonCopyable const &) DEFINE_NOEXCEPT = delete; 122 DEFINE_EXPLICIT DEFINE_CONSTEXPR CopyAssignable() DEFINE_NOEXCEPT = delete; 132 CopyAssignOnly& operator=(CopyAssignOnly &&) DEFINE_NOEXCEPT = delete; [all …]
|
| H A D | deleter_types.h | 62 void operator()(T* p) {delete p;} in operator() 90 void operator()(T* p) {delete [] p;} in operator() 124 void operator()(T* p) {delete p;} in operator() 150 void operator()(T* p) {delete [] p;} in operator() 183 void operator()(T* p) {delete p;} in operator() 204 void operator()(T* p) {delete [] p;} in operator() 232 void operator()(T* p) {delete p;} in operator() 251 void operator()(T* p) {delete [] p;} in operator() 314 void operator()(T* p) {delete p;} in operator() 338 void operator()(T* p) {delete [] p;} in operator() [all …]
|
| /llvm-project-15.0.7/clang/test/SemaOpenCLCXX/ |
| H A D | newdelete.clcpp | 15 void operator delete(void *ptr); 23 delete a; // expected-error {{'default delete' is not supported in C++ for OpenCL}} 39 delete a; // expected-error {{'default delete' is not supported in C++ for OpenCL}} 42 delete[] *a; // expected-error {{'default delete' is not supported in C++ for OpenCL}} 53 // User-defined delete is supported. 54 delete *b;
|
| /llvm-project-15.0.7/libcxx/test/std/iterators/iterator.requirements/iterator.concepts/ |
| H A D | incrementable.h | 76 not_default_initializable() = delete; 86 not_movable(not_movable&&) = delete; 138 noncopyable_with_difference_type(noncopyable_with_difference_type const&) = delete; 141 noncopyable_with_difference_type& operator=(noncopyable_with_difference_type const&) = delete; 152 noncopyable_without_difference_type(noncopyable_without_difference_type const&) = delete; 155 …oncopyable_without_difference_type& operator=(noncopyable_without_difference_type const&) = delete; 170 …opyable_with_difference_type_and_minus(noncopyable_with_difference_type_and_minus const&) = delete; 173 …h_difference_type_and_minus& operator=(noncopyable_with_difference_type_and_minus const&) = delete;
|
| /llvm-project-15.0.7/llvm/include/llvm/Support/ |
| H A D | AtomicOrdering.h | 37 bool operator<(AtomicOrderingCABI, AtomicOrderingCABI) = delete; 38 bool operator>(AtomicOrderingCABI, AtomicOrderingCABI) = delete; 39 bool operator<=(AtomicOrderingCABI, AtomicOrderingCABI) = delete; 40 bool operator>=(AtomicOrderingCABI, AtomicOrderingCABI) = delete; 68 bool operator<(AtomicOrdering, AtomicOrdering) = delete; 69 bool operator>(AtomicOrdering, AtomicOrdering) = delete; 70 bool operator<=(AtomicOrdering, AtomicOrdering) = delete; 71 bool operator>=(AtomicOrdering, AtomicOrdering) = delete;
|
| H A D | Alignment.h | 280 bool operator<=(Align Lhs, MaybeAlign Rhs) = delete; 281 bool operator>=(Align Lhs, MaybeAlign Rhs) = delete; 282 bool operator<(Align Lhs, MaybeAlign Rhs) = delete; 283 bool operator>(Align Lhs, MaybeAlign Rhs) = delete; 285 bool operator<=(MaybeAlign Lhs, Align Rhs) = delete; 286 bool operator>=(MaybeAlign Lhs, Align Rhs) = delete; 287 bool operator<(MaybeAlign Lhs, Align Rhs) = delete; 288 bool operator>(MaybeAlign Lhs, Align Rhs) = delete; 290 bool operator<=(MaybeAlign Lhs, MaybeAlign Rhs) = delete; 292 bool operator<(MaybeAlign Lhs, MaybeAlign Rhs) = delete; [all …]
|
| /llvm-project-15.0.7/lldb/tools/debugserver/source/ |
| H A D | JSON.h | 49 JSONString(const JSONString &s) = delete; 50 JSONString &operator=(const JSONString &s) = delete; 108 JSONNumber(const JSONNumber &s) = delete; 137 JSONTrue(const JSONTrue &s) = delete; 138 JSONTrue &operator=(const JSONTrue &s) = delete; 155 JSONFalse(const JSONFalse &s) = delete; 156 JSONFalse &operator=(const JSONFalse &s) = delete; 173 JSONNull(const JSONNull &s) = delete; 174 JSONNull &operator=(const JSONNull &s) = delete; 191 JSONObject(const JSONObject &s) = delete; [all …]
|
| /llvm-project-15.0.7/llvm/test/Transforms/FunctionAttrs/ |
| H A D | nofree.ll | 110 ; CHECK: delete.notnull: 114 ; CHECK: delete.end: 119 br i1 %isnull, label %delete.end, label %delete.notnull 121 delete.notnull: ; preds = %entry 124 br label %delete.end 126 delete.end: ; preds = %delete.notnull, %entry 138 ; CHECK: delete.notnull: 142 ; CHECK: delete.end: 147 br i1 %isnull, label %delete.end, label %delete.notnull 152 br label %delete.end [all …]
|
| /llvm-project-15.0.7/libcxxabi/src/ |
| H A D | cxa_guard_impl.h | 134 AtomicInt(AtomicInt const&) = delete; 135 AtomicInt& operator=(AtomicInt const&) = delete; 177 GuardByte() = delete; 178 GuardByte(GuardByte const&) = delete; 242 InitByteNoThreads() = delete; 279 LibcppMutex(LibcppMutex const&) = delete; 292 LibcppCondVar(LibcppCondVar const&) = delete; 387 LockGuard() = delete; 388 LockGuard(LockGuard const&) = delete; 547 GuardObject() = delete; [all …]
|
| /llvm-project-15.0.7/clang-tools-extra/clangd/support/ |
| H A D | Context.h | 47 Key(Key const &) = delete; 48 Key &operator=(Key const &) = delete; 49 Key(Key &&) = delete; 50 Key &operator=(Key &&) = delete; 89 Context(Context const &) = delete; 90 Context &operator=(const Context &) = delete; 191 WithContext(const WithContext &) = delete; 192 WithContext &operator=(const WithContext &) = delete; 193 WithContext(WithContext &&) = delete; 194 WithContext &operator=(WithContext &&) = delete;
|
| /llvm-project-15.0.7/clang/include/clang/ExtractAPI/Serialization/ |
| H A D | SerializerBase.h | 46 APISerializer() = delete; 47 APISerializer(const APISerializer &) = delete; 48 APISerializer(APISerializer &&) = delete; 49 APISerializer &operator=(const APISerializer &) = delete; 50 APISerializer &operator=(APISerializer &&) = delete;
|
| /llvm-project-15.0.7/compiler-rt/lib/sanitizer_common/ |
| H A D | sanitizer_mutex.h | 59 SpinMutex(const SpinMutex &) = delete; 60 void operator=(const SpinMutex &) = delete; 69 Semaphore(const Semaphore &) = delete; 70 void operator=(const Semaphore &) = delete; 371 Mutex(LinkerInitialized) = delete; 372 Mutex(const Mutex &) = delete; 373 void operator=(const Mutex &) = delete; 391 GenericScopedLock(const GenericScopedLock &) = delete; 392 void operator=(const GenericScopedLock &) = delete; 409 void operator=(const GenericScopedReadLock &) = delete; [all …]
|
| /llvm-project-15.0.7/lldb/include/lldb/DataFormatters/ |
| H A D | TypeSynthetic.h | 101 operator=(const SyntheticChildrenFrontEnd &) = delete; 127 delete; 129 operator=(const SyntheticValueProviderFrontEnd &) = delete; 273 SyntheticChildren(const SyntheticChildren &) = delete; 342 FrontEnd(const FrontEnd &) = delete; 343 const FrontEnd &operator=(const FrontEnd &) = delete; 354 TypeFilterImpl(const TypeFilterImpl &) = delete; 383 CXXSyntheticChildren(const CXXSyntheticChildren &) = delete; 447 FrontEnd(const FrontEnd &) = delete; 448 const FrontEnd &operator=(const FrontEnd &) = delete; [all …]
|